import React, { useState } from 'react';
import { View, Text, TouchableOpacity, Image, StyleSheet, Modal, Dimensions, ScrollView } from 'react-native';

const AccessibilityScreen = () => {
  const [showModal, setShowModal] = useState(false);
  const [contrastMode, setContrastMode] = useState(false);
  const [textSize, setTextSize] = useState(14);
  const [textSpacing, setTextSpacing] = useState(0);

  const toggleModal = () => {
    setShowModal(!showModal);
  };

  const toggleContrastMode = () => {
    setContrastMode(!contrastMode);
  };

  const increaseTextSize = () => {
    setTextSize(textSize + 2);
  };

  const decreaseTextSize = () => {
    setTextSize(textSize - 2);
  };

  const increaseTextSpacing = () => {
    setTextSpacing(textSpacing + 1);
  };

  const decreaseTextSpacing = () => {
    setTextSpacing(textSpacing - 1);
  };

  return (
    <View style={styles.container}>
      <TouchableOpacity style={styles.button} onPress={toggleModal}>
        <Image
          source={{
            uri: 'https://media.istockphoto.com/id/1181152834/vector/accsessibility-icon-universal-accsess-vector-icon.jpg?s=1024x1024&w=is&k=20&c=8g4ti6Aw-QXhug_dkbDDhBujNiCIWPnATli9NwRG-rg=',
          }}
          style={styles.image}
        />
      </TouchableOpacity>

      <Modal visible={showModal} animationType="slide" transparent>
        <View style={styles.modalContainer}>
          <View style={styles.modalContent}>
            <TouchableOpacity onPress={toggleContrastMode}>
              <Text style={[styles.optionText, contrastMode && styles.activeOption]}>
                Contrast Mode
              </Text>
            </TouchableOpacity>

            <TouchableOpacity onPress={increaseTextSize}>
              <Text style={styles.optionText}>Increase Text Size</Text>
            </TouchableOpacity>

            <TouchableOpacity onPress={decreaseTextSize}>
              <Text style={styles.optionText}>Decrease Text Size</Text>
            </TouchableOpacity>

            <TouchableOpacity onPress={increaseTextSpacing}>
              <Text style={styles.optionText}>Increase Text Spacing</Text>
            </TouchableOpacity>

            <TouchableOpacity onPress={decreaseTextSpacing}>
              <Text style={styles.optionText}>Decrease Text Spacing</Text>
            </TouchableOpacity>
          </View>

          <TouchableOpacity style={styles.closeButton} onPress={toggleModal}>
            <Text style={styles.closeButtonText}>Close</Text>
          </TouchableOpacity>
        </View>
      </Modal>

      {/* Display the function results in the main window */}
      <View style={styles.content}>
      <ScrollView>
        <Text
          style={[
            { fontSize: textSize, letterSpacing: textSpacing },
            contrastMode && styles.contrastText,
          ]}
        >
          Sample Content
        </Text> 
      </ScrollView>
      </View>
    </View>
  );
};

const windowWidth = Dimensions.get('window').width;
const windowHeight = Dimensions.get('window').height;

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
  },
  button: {
    position: 'absolute',
    top: '65%',
    left: -10,
    width: 80,
    height: 80,
    borderRadius: 20,
  },
  image: {
    width: '100%',
    height: '100%',
    borderRadius: 20,
  },
  modalContainer: {
    flex: null,
    alignItems: 'flex-start',
    justifyContent: 'center',
    backgroundColor: 'white',
    borderWidth: 2,
    borderColor: 'black',
    width: windowWidth * 0.6,
    height: windowHeight * 0.4,
    alignSelf: 'flex-start',
    marginLeft: windowWidth * 0.1,
    marginRight: windowWidth * 0.1,
    top:'50%',
    left: '-6%',
  },
  modalContent: {
    paddingHorizontal: 20,
    paddingVertical: 30,
  },
  optionText: {
    fontSize: 20,
    marginVertical: 5,
  },
  activeOption: {
    fontWeight: 'bold',
  },
  closeButton: {
    backgroundColor: '#2714cc',
    padding: 10,
    borderRadius: 5,
    marginBottom: 1,
    alignSelf: 'stretch',
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 'auto',
  },
  closeButtonText: {
    color: 'white',
    fontSize: 18,
  },
  content: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
  },
  contentText: {
    position: 'absolute',
    fontSize: 14,
    letterSpacing: 0,
    color: 'black',
  },
  contrastText: {
    color: 'white',
    backgroundColor: 'black',
  },
});

export default AccessibilityScreen;