import React, { useState,useEffect } from 'react';
import {useRoute} from '@react-navigation/native';
import axios from 'axios';
import { View, Text, TouchableOpacity, TextInput, StyleSheet, Dimensions, Image, Button, Modal, ScrollView, Alert } from 'react-native';
import * as Speech from 'expo-speech';
import Voice from 'react-native-voice';

export default function App({navigation}) {
  const route = useRoute();
  const [showModal, setShowModal] = useState(false);
  const [contrastMode, setContrastMode] = useState(false);
  const [textSize, setTextSize] = useState(14);
  const [textSpacing, setTextSpacing] = useState(0);

  const [progress, setprogress] = useState(0);
  const [qno, setqno] = useState(0);

  // var progress = 0;
  // var qno = 0;

  const toggleModal = () => {
    setShowModal(!showModal);
  };

  const toggleContrastMode = () => {
    setContrastMode(!contrastMode);
  };

  const increaseTextSize = () => {
    setTextSize(textSize + 2);
  };

  const decreaseTextSize = () => {
    setTextSize(textSize - 2);
  };

  const increaseTextSpacing = () => {
    setTextSpacing(textSpacing + 1);
  };

  const decreaseTextSpacing = () => {
    setTextSpacing(textSpacing - 1);
  };


  const questionText = "What is the capital of Sri Lanka?";
  const options = ['Kandy', 'Sri Jayawadhanapura Kotte', 'Galle'];

  const [selectedOption, setSelectedOption] = useState('');
  const [qOrder, setQOrder] = useState(0);
  const [answer, setAnswer] = useState('');
  const [questionArr, setQuestions] = useState([]);

  const [seconds, setSeconds] = useState(0);
  const [isRunning, setIsRunning] = useState(true);

  useEffect(() => {
    let interval = null;

    if (isRunning) {
      interval = setInterval(() => {
        setSeconds((prevSeconds) => prevSeconds + 1);
      }, 1000);
    } else if (!isRunning && seconds !== 0) {
      clearInterval(interval);
    }

    return () => clearInterval(interval);
  }, [isRunning, seconds]);

  //voice input(start)
  // const [isListening, setIsListening] = useState(false);
  // const [spokenText, setSpokenText] = useState('');
  //voice input(end)

  useEffect(() => {
    function getQuestions(){
        axios.get(`https://edusense-59f5b618df4b.herokuapp.com/question/getByGradeSub/${route.params.logged.grade}/${route.params.sub}`).then((res) => {
          setQuestions(res.data);
        }).catch((err) => {
            alert(err);
        })
    }
    getQuestions();
  }, []);

  const submitAnswer = async (qid) => {
    const newSub = {
      qid,
      sid:'temp',
      answer,
      duration:seconds,
      subject:'temp'
    }
    await axios.post('https://edusense-59f5b618df4b.herokuapp.com/submit/new', newSub)
    .then(response => {
      if(response.data === 'Saved'){
        Speech.speak('Answer saved', {
          rate: 0.6,
        });
        
      }
    })
    .catch(error => {
      Alert.alert(error);
    });
  };

  const speak = (q) => {
   Speech.speak('question ' + (qOrder+1));
   Speech.speak(q.question, {
    rate: 0.6,
  });
   Speech.speak('option 1 ' + q.option1);
   Speech.speak('option 2 ' + q.option2);
   Speech.speak('option 3 ' + q.option3);
  };

  const speakAnswer = (answer) => {
    Speech.speak('Your answer is ' + answer, {
     rate: 0.6,
   });
   Speech.speak('Click on the Save and Next button to save the answer and navigate to the next question, which is at the bottom of the page', {
    rate: 0.6,
  });
   };

  const handleOptionSelection = (answer) => {
    setAnswer(answer);
    speakAnswer(answer);
  };

  const handleBack = () => {
    // Logic to go back to the previous question
  };

  const handleSaveNext = async (qid, ans) => {
    // Logic to save the answer and navigate to the next question
    setqno(qno + 1);
    // qno = qno + 1;
    submitAnswer(qid);
    setAnswer('');
    if (answer == ans) {
      setprogress(progress + 1);
    }
    if(questionArr.length > (qOrder+1)){
    setQOrder(qOrder + 1);
    }
    else{
      // navigation.navigate('Start')

      Speech.speak('Your test is over ', {
        rate: 0.6,
      });
      Speech.speak('Congratulations ', {
        rate: 0.6,
      });
      setIsRunning(false);
      if (answer == ans) {
        navigation.navigate('Note',{
          marks: Math.round((progress+1)*100/(qOrder + 1)),
          time: seconds,
          logged:route.params.logged,
          q:qOrder + 1,
          s:route.params.sub
        });
      }
      else {
        navigation.navigate('Note',{
          marks: Math.round((progress)*100/(qOrder + 1)),
          time: seconds,
          logged:route.params.logged,
          q:qOrder + 1,
          s:route.params.sub
        });
      }
      setSeconds(0);
    }
  };

  const handleVoiceCommand = () => {
    // Logic to handle voice command for answering the question
  };

  const screenWidth = Dimensions.get('window').width;

  if(questionArr.length > 0){
  return (
    <View style={styles.container}>
      <TouchableOpacity style={styles.buttonAccess} onPress={toggleModal}>
        <Image
          source={{
            uri: 'https://media.istockphoto.com/id/1181152834/vector/accsessibility-icon-universal-accsess-vector-icon.jpg?s=1024x1024&w=is&k=20&c=8g4ti6Aw-QXhug_dkbDDhBujNiCIWPnATli9NwRG-rg=',
          }}
          style={styles.image}
        />
      </TouchableOpacity>

      <Modal visible={showModal} animationType="slide" transparent>
        <View style={styles.modalContainer}>
          <View style={styles.modalContent}>
            <TouchableOpacity onPress={toggleContrastMode}>
              <Text style={[styles.optionText, contrastMode && styles.activeOption]}>
                Contrast Mode
              </Text>
            </TouchableOpacity>

            <TouchableOpacity onPress={increaseTextSize}>
              <Text style={styles.optionText}>Increase Text Size</Text>
            </TouchableOpacity>

            <TouchableOpacity onPress={decreaseTextSize}>
              <Text style={styles.optionText}>Decrease Text Size</Text>
            </TouchableOpacity>

            <TouchableOpacity onPress={increaseTextSpacing}>
              <Text style={styles.optionText}>Increase Text Spacing</Text>
            </TouchableOpacity>

            <TouchableOpacity onPress={decreaseTextSpacing}>
              <Text style={styles.optionText}>Decrease Text Spacing</Text>
            </TouchableOpacity>
          </View>

          <TouchableOpacity style={styles.closeButton} onPress={toggleModal}>
            <Text style={styles.closeButtonText}>Close</Text>
          </TouchableOpacity>
        </View>
      </Modal>

      <View style={styles.contentContainer}>
      <Text style={styles.questionNumber}>{seconds}</Text>
      <Text></Text>
        <Text style={[
            { fontSize: textSize, letterSpacing: textSpacing },
            contrastMode && styles.contrastText,
          ]}>{`Question ${qOrder + 1}`}</Text>
        <Text style={[
            { fontSize: textSize, letterSpacing: textSpacing },
            contrastMode && styles.contrastText,
          ]}>{questionArr[qOrder].question}</Text>
        <TouchableOpacity
          style={styles.optionButton}
          onPress={() => handleOptionSelection(questionArr[qOrder].option1)}
        >
          <Text style={[
            { fontSize: textSize, letterSpacing: textSpacing },
            contrastMode && styles.contrastText,
          ]}>{`Option 1: ${questionArr[qOrder].option1}`}</Text>
        </TouchableOpacity>

        <TouchableOpacity
          style={styles.optionButton}
          onPress={() => handleOptionSelection(questionArr[qOrder].option2)}
        >
          <Text style={[
            { fontSize: textSize, letterSpacing: textSpacing },
            contrastMode && styles.contrastText,
          ]}>{`Option 2: ${questionArr[qOrder].option2}`}</Text>
        </TouchableOpacity>

        <TouchableOpacity
          style={styles.optionButton}
          onPress={() => handleOptionSelection(questionArr[qOrder].option3)}
        >
          <Text style={[
            { fontSize: textSize, letterSpacing: textSpacing },
            contrastMode && styles.contrastText,
          ]}>{`Option 3: ${questionArr[qOrder].option3}`}</Text>
        </TouchableOpacity>
        <Text></Text>
        <Text style={[
            { fontSize: textSize, letterSpacing: textSpacing },
            contrastMode && styles.contrastText,
          ]}>{`Answer : ${answer}`}</Text>

        <Text style={[
            { fontSize: textSize, letterSpacing: textSpacing },
            contrastMode && styles.contrastText,
          ]}>{`Correct Answers : ${progress}`}</Text>

     
     {/* {isListening && (
          <Text style={styles.spokenText}>Spoken Text: {spokenText}</Text> //voice input
        )} */}
    

      </View>
        <Button title="Press" onPress={() => {speak(questionArr[qOrder])}} />
        {answer ? (
          <>
            <TouchableOpacity style={[styles.button, styles.saveNextButton]} onPress={() => {
              handleSaveNext(questionArr[qOrder]._id, questionArr[qOrder].answer);
              if (questionArr[qOrder].answer == answer) {
                // setprogress(progress + 1);
              }
              }}>
              <Text style={styles.buttonText}>Save & Next</Text>
            </TouchableOpacity>
          </>
        ):(
          <>
            
          </>
        )}
    </View>
  );
  }
  else{
    return (
    <View style={styles.container}>
      <Text style={styles.questionNumber}>Loading...</Text>
    </View>
    );
  }
};

const windowWidth = Dimensions.get('window').width;
const windowHeight = Dimensions.get('window').height;

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  accessibilityIcon: {
    position: 'absolute',
    top: '70%',
    left: -10,
    width: 80,
    height: 80,
    borderRadius: 20,
  },
  contentContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'flex-start',
    marginHorizontal: 20,
  },
  button: {
    backgroundColor: '#2714cc',
    padding: 10,
    borderRadius: 5,
    marginTop: 10,
    height: 80,
  },
  buttonText: {
    color: '#FFFFFF',
    fontSize: 16,
    fontWeight: 'bold',
    textAlign: 'center',
  },
  questionNumber: {
    fontSize: 16,
    fontWeight: 'bold',
    marginBottom: 10,
  },
  questionText: {
    fontSize: 18,
    fontWeight: 'bold',
    marginBottom: 20,
  },
  optionButton: {
    marginBottom: 10,
  },
  optionText: {
    fontSize: 18,
    marginLeft: 10,
  },
  answerText: {
    fontSize: 18,
    marginLeft: 10,
    color:'green'
  },
  //voice input start
  spokenText: {
    fontSize: 16,
    marginTop: 10,
    textAlign: 'center',
  },
  //voice input end
  voiceCommandButton: {
    backgroundColor: '#CCCCCC',
    padding: 10,
    borderRadius: 5,
    marginTop: 20,
  },
  voiceCommandButtonText: {
    color: '#000000',
    fontSize: 16,
    fontWeight: 'bold',
    textAlign: 'center',
  },
  saveNextButton: {
    width: '100%',
    paddingVertical: 20,
    paddingBottom: 20, 
  },
  //voice input start
  doubleTapOverlay: {
    ...StyleSheet.absoluteFillObject,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
  },
  doubleTapText: {
    color: '#FFFFFF',
    fontSize: 20,
    fontWeight: 'bold',
  },
  buttonAccess: {
    position: 'absolute',
    top: '65%',
    left: -10,
    width: 80,
    height: 80,
    borderRadius: 20,
  },
  image: {
    width: '100%',
    height: '100%',
    borderRadius: 20,
  },
  modalContainer: {
    flex: null,
    alignItems: 'flex-start',
    justifyContent: 'center',
    backgroundColor: 'white',
    borderWidth: 2,
    borderColor: 'black',
    width: windowWidth * 0.6,
    height: windowHeight * 0.4,
    alignSelf: 'flex-start',
    marginLeft: windowWidth * 0.1,
    marginRight: windowWidth * 0.1,
    top:'50%',
    left: '-6%',
  },
  modalContent: {
    paddingHorizontal: 20,
    paddingVertical: 30,
  },
  optionText: {
    fontSize: 20,
    marginVertical: 5,
  },
  activeOption: {
    fontWeight: 'bold',
  },
  closeButton: {
    backgroundColor: '#2714cc',
    padding: 10,
    borderRadius: 5,
    marginBottom: 1,
    alignSelf: 'stretch',
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 'auto',
  },
  closeButtonText: {
    color: 'white',
    fontSize: 18,
  },
  content: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
  },
  contentText: {
    position: 'absolute',
    fontSize: 14,
    letterSpacing: 0,
    color: 'black',
  },
  contrastText: {
    color: 'white',
    backgroundColor: 'black',
  },
  //voice input end


});
