import React, { useState } from 'react';
import { View, Text, TextInput, TouchableOpacity, StyleSheet, Alert, ScrollView } from 'react-native';
// import DateTimePickerModal from "react-native-modal-datetime-picker";
import axios from 'axios';

const RegistrationForm = ({navigation}) => {
  const [studentName, setStudentName] = useState('');
  const [studentPhone, setStudentPhone] = useState('');
  const [studentEmail, setStudentEmail] = useState('');
  const [grade, setGrade] = useState('');
  const [disability, setDisability] = useState('');
  const [password, setPassword] = useState('');

  const handleSubmit = async () => {

    
    // Validation
  if (!studentName) {
    Alert.alert('Validation Error', 'Please enter student name');
    return;
  }
  if (!studentPhone || !/^[0-9]{10}$/i.test(studentPhone)) {
    Alert.alert('Validation Error', 'Please enter valid student phone number');
    return;
  }
  if (!studentEmail || !/^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$/i.test(studentEmail)) {
    Alert.alert('Validation Error', 'Please enter valid student email');
    return;
  }
  if (!password || password.length < 6) {
    Alert.alert('Validation Error', 'Password should have at least 6 characters');
    return;
  }


    const newStudent = {
        name: studentName,
        phone: studentPhone,
        email: studentEmail,
        grade: grade,
        disability: disability,
        password: password,
    }
    await axios.post('https://edusense-59f5b618df4b.herokuapp.com/student/upload', newStudent)
    .then(response => {
      Alert.alert(response.data);
      navigation.navigate('Login');
    })
    .catch(error => {
      Alert.alert('Registration Failed', 'Student registration failed. Please try again.');
    });
  };

  return (
    <View style={styles.container}>
      <ScrollView>
      <Text style={styles.label}>Student Name</Text>
      <TextInput
        style={styles.input}
        value={studentName}
        onChangeText={setStudentName}
      />


      <Text style={styles.label}>Student Phone</Text>
      <TextInput
        style={styles.input}
        value={studentPhone}
        onChangeText={setStudentPhone}
        keyboardType='phone-pad'
      />


      <Text style={styles.label}>Student Email</Text>
      <TextInput
        style={styles.input}
        value={studentEmail}
        onChangeText={setStudentEmail}
        keyboardType='email-address'
      />


      <Text style={styles.label}>Password</Text>
      <TextInput
        style={styles.input}
        value={password}
        onChangeText={setPassword}
        secureTextEntry={true}
      />
      <Text style={styles.label}>Grade : {grade}</Text>
      <View
      style={{
          flexDirection: 'row',
          height: 80,
          padding: 20,
      }}>
      <TouchableOpacity style={styles.button2} onPress={() => setGrade('1')}>
      <Text style={styles.button2Text}> 1</Text>
      </TouchableOpacity>
      <TouchableOpacity style={styles.button2} onPress={() => setGrade('2')}>
      <Text style={styles.button2Text}> 2</Text>
      </TouchableOpacity>
      <TouchableOpacity style={styles.button2} onPress={() => setGrade('3')}>
      <Text style={styles.button2Text}> 3</Text>
      </TouchableOpacity>
      <TouchableOpacity style={styles.button2} onPress={() => setGrade('4')}>
      <Text style={styles.button2Text}> 4</Text>
      </TouchableOpacity>
      <TouchableOpacity style={styles.button2} onPress={() => setGrade('5')}>
      <Text style={styles.button2Text}> 5</Text>
      </TouchableOpacity>
      </View>

      
      <Text style={styles.label}>Disability : {disability}</Text>
      <View
      style={{
          flexDirection: 'row',
          height: 80,
          padding: 20,
      }}>
      <TouchableOpacity style={styles.button2} onPress={() => setDisability('Blind')}>
      <Text style={styles.button2Text}>Blind</Text>
      </TouchableOpacity>
      <TouchableOpacity style={styles.button2} onPress={() => setDisability('Partially-Blind')}>
      <Text style={styles.button2Text}>Partially Blind</Text>
      </TouchableOpacity>
      <TouchableOpacity style={styles.button2} onPress={() => setDisability('Color-Blind')}>
      <Text style={styles.button2Text}>Color Blind</Text>
      </TouchableOpacity>
      </View>
     
      <TouchableOpacity style={styles.button} onPress={handleSubmit}>
        <Text style={styles.buttonText}>Submit</Text>
      </TouchableOpacity>
  </ScrollView>
</View>
);
};

const styles = StyleSheet.create({
container: {
flex: 1,
padding: 20,
backgroundColor: '#fff',
},
label: {
fontSize: 18,
fontWeight: 'bold',
marginTop: 10,
},
input: {
borderWidth: 1,
borderColor: '#ccc',
borderRadius: 5,
padding: 10,
fontSize: 18,
marginTop: 5,
marginBottom: 10,
},
button: {
backgroundColor: '#008080',
padding: 10,
borderRadius: 5,
marginTop: 20,
},
button2: {
  marginRight: 5,
  backgroundColor: 'black',
  padding: 10,
  borderRadius: 5,
},
button2Text: {
color: 'white',
fontSize: 16,
textAlign: 'center',
},
buttonText: {
color: '#fff',
fontSize: 18,
textAlign: 'center',
},
});

export default RegistrationForm;
