import React, { Component } from 'react';
import { View, Text, TextInput, Button, StyleSheet, TouchableOpacity } from 'react-native';

class StudentRegistrationForm extends Component {
  constructor(props) {
    super(props);
    this.state = {
      studentName: '',
      email: '',
      contactNumber: '',
      grade: '',
      disability: '',
    };

    this.gradeOptions = ['Grade 1', 'Grade 2', 'Grade 3', 'Grade 4', 'Grade 5'];
    this.disabilityOptions = ['Blind', 'Partially Blind', 'Color Blind'];
  }

  handleInputChange = (field, value) => {
    this.setState({ [field]: value });
  };

  handleSaveDetails = () => {
    // You can save the details to your database or perform other actions here.
    console.log('Saving details:', this.state);
  };

  handleGradeSelect = (selectedGrade) => {
    this.setState({ grade: selectedGrade });
  };

  handleDisabilitySelect = (selectedDisability) => {
    this.setState({ disability: selectedDisability });
  };

  handleNext = () => {
    // Implement your "Next" button functionality here.
  };

  renderGradeButtons() {
    return this.gradeOptions.map((grade, index) => (
      <TouchableOpacity
        key={index}
        style={[
          styles.gradeButton,
          this.state.grade === grade ? styles.selectedGradeButton : null,
        ]}
        onPress={() => this.handleGradeSelect(grade)}
      >
        <Text style={styles.gradeButtonText}>{grade}</Text>
      </TouchableOpacity>
    ));
  }

  renderDisabilityButtons() {
    return this.disabilityOptions.map((disability, index) => (
      <TouchableOpacity
        key={index}
        style={[
          styles.disabilityButton,
          this.state.disability === disability ? styles.selectedDisabilityButton : null,
        ]}
        onPress={() => this.handleDisabilitySelect(disability)}
      >
        <Text style={styles.disabilityButtonText}>{disability}</Text>
      </TouchableOpacity>
    ));
  }

  render() {
    return (
      <View style={styles.container}>
        <Text style={styles.title}>Student Registration</Text>
        <TextInput
          style={styles.input}
          placeholder="Student Name"
          onChangeText={(text) => this.handleInputChange('studentName', text)}
        />
        <TextInput
          style={styles.input}
          placeholder="Email"
          onChangeText={(text) => this.handleInputChange('email', text)}
        />
        <TextInput
          style={styles.input}
          placeholder="Contact Number"
          onChangeText={(text) => this.handleInputChange('contactNumber', text)}
        />

        <View style={styles.gradeButtonsContainer}>
          {this.renderGradeButtons()}
        </View>

        <View style={styles.disabilityButtonsContainer}>
          {this.renderDisabilityButtons()}
        </View>

        <TextInput
          style={styles.input}
          placeholder="Other Disability (if applicable)"
          onChangeText={(text) => this.handleInputChange('disability', text)}
        />

        <View style={styles.buttonContainer}>
          <TouchableOpacity
            style={styles.saveButton}
            onPress={this.handleSaveDetails}
          >
            <Text style={styles.buttonText}>Save Details</Text>
          </TouchableOpacity>
          <TouchableOpacity
            style={styles.editButton}
            onPress={this.handleNext}
          >
            <Text style={styles.buttonText}>Edit</Text>
          </TouchableOpacity>
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    padding: 20,
  },
  title: {
    fontSize: 24,
    fontWeight: 'bold',
    marginBottom: 20,
  },
  input: {
    borderWidth: 1,
    borderColor: '#ccc',
    padding: 10,
    marginBottom: 10,
  },
  gradeButtonsContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    marginBottom: 10,
  },
  gradeButton: {
    flex: 1,
    borderWidth: 1,
    borderColor: '#ccc',
    alignItems: 'center',
    padding: 10,
  },
  selectedGradeButton: {
    backgroundColor: '#007bff',
  },
  gradeButtonText: {
    fontSize: 16,
  },
  disabilityButtonsContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    marginBottom: 10,
  },
  disabilityButton: {
    flex: 1,
    borderWidth: 1,
    borderColor: '#ccc',
    alignItems: 'center',
    padding: 10,
  },
  selectedDisabilityButton: {
    backgroundColor: '#007bff',
  },
  disabilityButtonText: {
    fontSize: 16,
  },
  buttonContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    position: 'absolute',
    bottom: 0,
    left: 0,
    right: 0,
    height: 80,
  },
  saveButton: {
    flex: 1,
    backgroundColor: '#0000FF',
    justifyContent: 'center',
    alignItems: 'center',
    width: '50%',
  },
  editButton: {
    flex: 1,
    backgroundColor: '#0000FF',
    justifyContent: 'center',
    alignItems: 'center',
    width: '50%',
  },
  buttonText: {
    color: 'white',
    fontSize: 16,
  },
});

export default StudentRegistrationForm;
