import React, { useState } from 'react';
import { View, Text, Button, Dimensions, Image, Alert } from 'react-native';

const StudentProfile = () => {
  // Sample data
  const student = {
    name: 'John Doe',
    email: 'johndoe@example.com',
    contactNumber: '1234567890',
    grade: 'Grade 5',
    disability: 'Partially Blind',
    profilePicture: 'https://lh3.googleusercontent.com/CXuKCsN8Xk0nA2x8JBfaqnXPvhjkp8FeEzF8RnLFulAFYUjSMm51pOH5fYbE-Y7gkLKFWlvCT3mqYDsvwJwNMf216Ocezvoen3Vj8YBA' 
  };

  // Handle edit action
  const handleEdit = () => {
    // Add your edit logic here
    console.log('Edit button pressed');
  };

  // Handle delete action
  const handleDelete = () => {
    Alert.alert(
      'Delete Account',
      'Are you sure you want to delete this account?',
      [
        { text: 'Cancel', style: 'cancel' },
        { text: 'OK', onPress: confirmDelete },
      ]
    );
  };

  const confirmDelete = () => {
    // Add your delete logic here
    console.log('Account deleted');
  };

  return (
    <View style={styles.container}>
      <Text style={styles.title}>Student Profile</Text>

      <Image source={{ uri: student.profilePicture }} style={styles.profilePicture} />

      <View style={styles.fieldContainer}>
        <Text style={styles.fieldTitle}>Student Name:</Text>
        <Text style={styles.fieldValue}>{student.name}</Text>
      </View>

      <View style={styles.fieldContainer}>
        <Text style={styles.fieldTitle}>Email:</Text>
        <Text style={styles.fieldValue}>{student.email}</Text>
      </View>

      <View style={styles.fieldContainer}>
        <Text style={styles.fieldTitle}>Contact Number:</Text>
        <Text style={styles.fieldValue}>{student.contactNumber}</Text>
      </View>

      <View style={styles.fieldContainer}>
        <Text style={styles.fieldTitle}>Grade:</Text>
        <Text style={styles.fieldValue}>{student.grade}</Text>
      </View>

      <View style={styles.fieldContainer}>
        <Text style={styles.fieldTitle}>Disability:</Text>
        <Text style={styles.fieldValue}>{student.disability}</Text>
      </View>

      <Image
        source={{ uri: 'https://media.istockphoto.com/id/1181152834/vector/accsessibility-icon-universal-accsess-vector-icon.jpg?s=1024x1024&w=is&k=20&c=8g4ti6Aw-QXhug_dkbDDhBujNiCIWPnATli9NwRG-rg=' }} 
        style={styles.accessibilityIcon}
      />

      <View style={styles.buttonsContainer}>
        <Button title="     Edit Details     " onPress={handleEdit} color="#2714cc" />
        <Button title="  Delete Account  " onPress={handleDelete} color="#2714cc" />
      </View>
    </View>
  );
};

const styles = {
  container: {
    flex: 1,
    alignItems: 'center',
    marginTop: 50,
    paddingHorizontal: 20,
    paddingTop: 20,
    backgroundColor: '#f5f5f5',
    fontSize: 20,

  },
  title: {
    fontSize: 24,
    fontWeight: 'bold',
    marginBottom: 70,
    color: '#333',
  },
    profilePicture: {
    width: 150,
    height: 150,
    borderRadius: 75,
    marginBottom: 25,
  },
  fieldContainer: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: 10,
  },
  fieldTitle: {
    fontWeight: 'bold',
    marginRight: 10,
    fontSize: 18,
  },
  fieldValue: {
    fontSize: 18,
  },
  buttonsContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    width: Dimensions.get('window').width,
    position: 'absolute',
    bottom: 0,
    marginBottom: 10,
    height: 130,

  },
  deleteButton: {
    flex: 1,
    marginRight: 10,
    height: 80,
    backgroundColor: '#FF0000',
  },
  editButton: {
    flex: 1,
    marginLeft: 10,
    height: 50,
    backgroundColor: '#00FF00',
  },
  accessibilityIcon: {
    position: 'absolute',
    top: '65%',
    left: -10,
    width: 80,
    height: 80,
    borderRadius: 20,
  },
};

export default StudentProfile;