import React, { useState } from 'react';
import {useRoute} from '@react-navigation/native';
import { View, Button, Text, Dimensions, StyleSheet, TouchableOpacity, Image } from 'react-native';

const { width } = Dimensions.get('window');

const ExamSelectionScreen = ({navigation}) => {
  const [selectedSubject, setSelectedSubject] = useState(null);
  const route = useRoute();
  const handleSubjectSelection = (subject) => {
    setSelectedSubject(subject);
  };

  const handleGetExam = () => {
    // Logic to proceed with the exam using the selectedSubject
    navigation.navigate('Exam',{
      logged:route.params.logged,
      sub: selectedSubject
    });
  };

  return (
    <View style={styles.container}>
      <Text style={styles.heading}>Select Exam Subject</Text>
      <View style={styles.optionsContainer}>
        
        <View style={styles.option}>
          <Text style={styles.optionText}>Option 1:</Text>
          <Button title="English" onPress={() => handleSubjectSelection('english')} color="#808080" />
        </View>
        
        <View style={styles.option}>
          <Text style={styles.optionText}>Option 2:</Text>
          <Button title="Environmental Studies" onPress={() => handleSubjectSelection('environmental studies')} color="#808080" />
        </View>
        <View style={styles.option}>
          <Text style={styles.optionText}>Option 3:</Text>
          <Button title="Mathematics" onPress={() => handleSubjectSelection('maths')} color="#808080" />
        </View>
        <Text style={styles.heading}>{selectedSubject} selected</Text>
      </View>
      {selectedSubject ? (
          <>
            <TouchableOpacity style={styles.buttonContainer} >
                <Button title="Get the Exam" onPress={handleGetExam} color="#2714cc" height="130"  />
            </TouchableOpacity>
          </>
        ):(
          <>
            
          </>
        )}

      <Image
        source={{ uri: 'https://media.istockphoto.com/id/1181152834/vector/accsessibility-icon-universal-accsess-vector-icon.jpg?s=1024x1024&w=is&k=20&c=8g4ti6Aw-QXhug_dkbDDhBujNiCIWPnATli9NwRG-rg=' }} 
        style={styles.accessibilityIcon}
      />

    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#f5f5f5',
  },
  heading: {
    fontSize: 24,
    fontWeight: 'bold',
    marginBottom: 20,
    color: '#333',
  },
  optionsContainer: {
    alignItems: 'flex-start',
    marginBottom: 40,
    marginLeft: 20,
  },
  option: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: 20,
  },
  optionText: {
    marginRight: 5,
    color: '#808080',
  },
  accessibilityIcon: {
    position: 'absolute',
    top: '65%',
    left: -10,
    width: 80,
    height: 80,
    borderRadius: 20,
  },
  buttonContainer: {
    justifyContent: 'center',
    alignItems: 'center',
    position: 'absolute',
    bottom: 2,
    width:'110%',
    paddingHorizontal: 20,
    height: 80,
    backgroundColor: "#2714cc"
  },
  button: {
    height: 130,
  },
});

export default ExamSelectionScreen;
