const path = require('path');
const express = require('express');
const Question = require('../models/question');
const router = express.Router();

router.post(
    '/new',
    async (req, res) => {

      try {
        const {question, option1, option2, option3, answer, subject, grade} = req.body;
        const newQuestion = new Question({
          question,
          option1,
          option2,
          option3,
          answer,
          subject,
          grade
        });
        await newQuestion.save();
        res.json('Saved');
      } catch (error) {
        res.json('Error');
      }
    },
    (error, req, res, next) => {
      if (error) {
        res.status(500).send(error.message);
      }
    }
  );
  
  router.get('/getAll', async (req, res) => {
    try {
      const Questions = await Question.find({});
      const sortedByCreationDate = Questions.sort(
      (a, b) => b.createdAt - a.createdAt
      );
      res.send(sortedByCreationDate);
    } catch (error) {
      res.json('Error while getting list of Questions. Try again later.');
    }
  });

  router.get('/getBySub/:sub', async (req, res) => {
    let subject = req.params.sub;
    try {
      const Questions = await Question.find({subject:subject});
      const sortedByCreationDate = Questions.sort(
      (a, b) => b.createdAt - a.createdAt
      );
      res.send(sortedByCreationDate);
    } catch (error) {
      res.json('Error while getting list of Questions. Try again later.');
    }
  });

  router.get('/getByGrade/:grade', async (req, res) => {
    let grade = req.params.grade;
    try {
      const Questions = await Question.find({grade:grade});
      const sortedByCreationDate = Questions.sort(
      (a, b) => b.createdAt - a.createdAt
      );
      res.send(sortedByCreationDate);
    } catch (error) {
      res.json('Error while getting list of Questions. Try again later.');
    }
  });

  router.get('/getByGradeSub/:grade/:sub', async (req, res) => {
    let grade = req.params.grade;
    let subject = req.params.sub;
    try {
      const Questions = await Question.find({grade:grade, subject:subject});
      const sortedByCreationDate = Questions.sort(
      (a, b) => b.createdAt - a.createdAt
      );
      res.send(sortedByCreationDate);
    } catch (error) {
      res.json('Error while getting list of Questions. Try again later.');
    }
  });
  
  router.route('/delete/:id').delete(async (req, res) => {
  
    try {
        let id = req.params.id;
        await Question.findByIdAndDelete(id).then(()=>{
        res.status(200).send({status: "Deleted"});
      }).catch((err)=>{
        console.log(err);
        res.status(500).send({status: "Error with delete"});
      });
      
    } catch (error) {
      res.status(400).send('Error');
    }
  });
  
  router.route('/edit/:id').put(async (req, res) => {
  
    let id = req.params.id;
    const {question, option1, option2, option3, answer, subject, grade} = req.body;

    const update = await Question.findByIdAndUpdate(id, {
      question:question,
      option1:option1,
      option2:option2,
      option3:option3,
      answer:answer,
      subject:subject,
      grade:grade
    }).then(()=>{
        res.json("Updated");
    }).catch((err)=>{
        res.json("Error");
    })
  
  });
  
  module.exports = router;