const path = require('path');
const express = require('express');
const Submission = require('../models/submission');
const router = express.Router();

router.post(
    '/new',
    async (req, res) => {

      try {
        const {qid, sid, answer, duration, subject} = req.body;
        const newSubmission = new Submission({
          qid,
          sid,
          answer,
          duration,
          subject
        });
        await newSubmission.save();
        res.json('Saved');
      } catch (error) {
        res.json('Error');
      }
    },
    (error, req, res, next) => {
      if (error) {
        res.status(500).send(error.message);
      }
    }
  );
  
  router.get('/getAll', async (req, res) => {
    try {
      const Submissions = await Submission.find({});
      const sortedByCreationDate = Submissions.sort(
      (a, b) => b.createdAt - a.createdAt
      );
      res.send(sortedByCreationDate);
    } catch (error) {
      res.json('Error while getting list of Submissions. Try again later.');
    }
  });

  router.get('/getBySidSub/:sid/:sub', async (req, res) => {
    let sid = req.params.sid;
    let subject = req.params.sub;
    try {
      const Submissions = await Submission.find({sid:sid, subject:subject});
      const sortedByCreationDate = Submissions.sort(
      (a, b) => b.createdAt - a.createdAt
      );
      res.send(sortedByCreationDate);
    } catch (error) {
      res.json('Error while getting list of Submissions. Try again later.');
    }
  });
  
  router.route('/delete/:id').delete(async (req, res) => {
  
    try {
        let id = req.params.id;
        await Submission.findByIdAndDelete(id).then(()=>{
        res.status(200).send({status: "Deleted"});
      }).catch((err)=>{
        console.log(err);
        res.status(500).send({status: "Error with delete"});
      });
      
    } catch (error) {
      res.status(400).send('Error');
    }
  });
  
  router.route('/edit/:id').put(async (req, res) => {
  
    let id = req.params.id;
    const {qid, sid, answer, duration, subject} = req.body;

    const update = await Submission.findByIdAndUpdate(id, {
        qid, sid, answer, duration, subject
    }).then(()=>{
        res.json("Updated");
    }).catch((err)=>{
        res.json("Error");
    })
  
  });
  
  module.exports = router;